@@ -1,12 +1,7 @@
 package Business::CanadaPost;
-BEGIN {
-  $Business::CanadaPost::AUTHORITY = 'cpan:YANICK';
-}
-{
-  $Business::CanadaPost::VERSION = '1.06';
-}
-# ABSTRACT: Fetch shipping costs for Canada Post
-
+our $AUTHORITY = 'cpan:YANICK';
+# ABSTRACT: Fetch shipping costs for Canada Post (DEPRECATED)
+$Business::CanadaPost::VERSION = '1.07';
 use strict;
 use LWP;
 use vars qw($VERSION @ISA @EXPORT);
@@ -378,14 +373,14 @@ sub _error # {{{
 				'You must specify your Canada Post merchant ID!',
 				'Failed sending to Canada Posts servers!');
 	my @frenchmessages  = ('Vous devez indiquer quelques pour transporter!',
-				'Vous devez indiquer un code postal valide pour les expditions Canadiannes!',
-				'Vous devez indiquer un tat pour les expditions amricaines!',
-				'Vous devez indiquer le pays que vous voulez embarquer !',
-				'Les langues valides sont Anglaises et Franaises',
-				'Les units valides sont mtriques (cm et kg) ou impriales (po et lv)',
+				'Vous devez indiquer un code postal valide pour les expÃ©ditions Canadiannes!',
+				'Vous devez indiquer un Ã©tat pour les expÃ©ditions amÃ©ricaines!',
+				'Vous devez indiquer le pays que vous voulez embarquer à!',
+				'Les langues valides sont Anglaises et Françaises',
+				'Les unitÃ©s valides sont mÃ©triques (cm et kg) ou impÃ©riales (po et lv)',
 				'Vous devez indiquer une taille, une largeur, et une longueur pour chaque article.',
 				'Vous devez indiquer votre identification du Postes Canada!',
-				'Envoi chou aux serveurs du Postes Canada!');
+				'Envoi Ã©chouÃ© aux serveurs du Postes Canada!');
 
 	if ($msgnum == 0)
 	{
@@ -491,7 +486,7 @@ sub buildXML # {{{
 
 	}
 	elsif (uc($self->{'country'}) eq 'UNITED STATES' or uc($self->{'country'} eq 'US')
-			or uc($self->{'country'}) eq 'TATS-UNIS')
+			or uc($self->{'country'}) eq 'ÉTATS-UNIS')
 	{
 		#canada post says that all they require for now is country and provorstate; however,
 		#zipcodes will be used in the future...
@@ -516,17 +511,19 @@ sub buildXML # {{{
 
 1;
 
-
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-Business::CanadaPost - Fetch shipping costs for Canada Post
+Business::CanadaPost - Fetch shipping costs for Canada Post (DEPRECATED)
 
 =head1 VERSION
 
-version 1.06
+version 1.07
 
 =head1 SYNOPSIS
 
@@ -556,6 +553,9 @@ version 1.06
 
 =head1 DESCRIPTION
 
+B<DEPRECATED>: The service this module is an API will be decommissioned 
+as of September 2025 (see L<https://sellonline-cybervente.canadapost-postescanada.ca/index-e.html>).
+
 Business::CanadaPost is a Perl library created to allow users to fetch real-time options and pricing quotes
 on shipments sent from Canada using Canada Post.
 
@@ -911,15 +911,10 @@ Yanick Champoux <yanick@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2005 by Justin Wheeler.
+This software is Copyright (c) 2025, 2011 by Justin Wheeler.
 
 This is free software, licensed under:
 
   The GNU General Public License, Version 2, June 1991
 
 =cut
-
-
-__END__
-
-
